#include "program-6-server.h"

#include <assert.h>
#include <stdio.h>

/* You need to implement this function. */
void register_objects(CORBA_ORB orb, CORBA_BOA boa, int argc, char **argv,
                      CORBA_Environment *ev);

int main(int argc, char **argv)
{
	CORBA_Environment ev;
	CORBA_ORB orb;
	CORBA_BOA boa;
	if (argc < 3) {
		fprintf(stderr, "usage: %s [-ORBipaddr (local host ip address)] -OAport (portnum) ...\n", argv[0]);
		exit(1);
	}

	orb = CORBA_ORB_init(&argc, argv, 0, &ev);
	if (ev._major != CORBA_NO_EXCEPTION) {
		fprintf(stderr, "%s exception: unable to initialize ORB.\n", CORBA_exception_id(&ev));
		exit(1);
	}
	boa = CORBA_ORB_BOA_init(orb, &argc, argv, 0, &ev);
	if (ev._major != CORBA_NO_EXCEPTION) {
		fprintf(stderr, "%s exception: unable to initialize Object adapter.\n", CORBA_exception_id(&ev));
		exit(1);
	}
	register_objects(orb, boa, argc, argv, &ev);
	if (ev._major != CORBA_NO_EXCEPTION)
		fprintf(stderr, "ERROR: unable to register object implementations.\n");
	else {
		CORBA_BOA_impl_is_ready(boa, &ev);
	}
	if (ev._major != CORBA_NO_EXCEPTION) {
		fprintf(stderr, "%s exception encountered.\n", CORBA_exception_id(&ev));
		exit(1);
	}
	return 0;
}
void flick_marshal_stub_sa(flick_marshal_stream_t _stream, const struct sa *_data)
{
  flick_iiop_encode_new_glob(8);
  flick_iiop_encode_new_chunk(8);
  flick_cdr_encode_signed32(0, _data->a);
  flick_cdr_encode_signed32(4, _data->b);
  flick_iiop_encode_end_chunk(8);
  flick_iiop_encode_end_glob(8);
}

void flick_unmarshal_stub_sa(flick_marshal_stream_t _stream, struct sa *_data)
{
  flick_iiop_decode_new_glob(8);
  flick_iiop_decode_new_chunk(8);
  flick_cdr_decode_signed32(0, _data->a);
  flick_cdr_decode_signed32(4, _data->b);
  flick_iiop_decode_end_chunk(8);
  flick_iiop_decode_end_glob(8);
}

void flick_unmarshal_stub_sa_swap(flick_marshal_stream_t _stream, struct sa *_data)
{
  flick_iiop_decode_new_glob(8);
  flick_iiop_decode_new_chunk(8);
  flick_cdr_swap_decode_signed32(0, _data->a);
  flick_cdr_swap_decode_signed32(4, _data->b);
  flick_iiop_decode_end_chunk(8);
  flick_iiop_decode_end_glob(8);
}

void flick_marshal_stub_sb(flick_marshal_stream_t _stream, const struct sb *_data)
{
  flick_iiop_encode_new_glob(16);
  flick_iiop_encode_new_chunk(16);
  flick_cdr_encode_signed32(0, _data->a.a);
  flick_cdr_encode_signed32(4, _data->a.b);
  flick_cdr_encode_signed32(8, _data->b.a);
  flick_cdr_encode_signed32(12, _data->b.b);
  flick_iiop_encode_end_chunk(16);
  flick_iiop_encode_end_glob(16);
}

void flick_unmarshal_stub_sb(flick_marshal_stream_t _stream, struct sb *_data)
{
  flick_iiop_decode_new_glob(16);
  flick_iiop_decode_new_chunk(16);
  flick_cdr_decode_signed32(0, _data->a.a);
  flick_cdr_decode_signed32(4, _data->a.b);
  flick_cdr_decode_signed32(8, _data->b.a);
  flick_cdr_decode_signed32(12, _data->b.b);
  flick_iiop_decode_end_chunk(16);
  flick_iiop_decode_end_glob(16);
}

void flick_unmarshal_stub_sb_swap(flick_marshal_stream_t _stream, struct sb *_data)
{
  flick_iiop_decode_new_glob(16);
  flick_iiop_decode_new_chunk(16);
  flick_cdr_swap_decode_signed32(0, _data->a.a);
  flick_cdr_swap_decode_signed32(4, _data->a.b);
  flick_cdr_swap_decode_signed32(8, _data->b.a);
  flick_cdr_swap_decode_signed32(12, _data->b.b);
  flick_iiop_decode_end_chunk(16);
  flick_iiop_decode_end_glob(16);
}

void flick_marshal_stub_long_list(flick_marshal_stream_t _stream, const long_list *_data)
{
  flick_iiop_encode_new_glob(4);
  flick_iiop_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->long_list_len);
  flick_iiop_encode_end_chunk(4);
  flick_iiop_encode_end_glob(4);
  flick_iiop_encode_new_glob(4 * _data->long_list_len);
  flick_iiop_encode_new_chunk(4 * _data->long_list_len);
  flick_cdr_encode_bcopy(0, _data->long_list_val, 4 * _data->long_list_len);
  flick_iiop_encode_end_chunk(4 * _data->long_list_len);
  flick_iiop_encode_end_glob(4 * _data->long_list_len);
}

void flick_unmarshal_stub_long_list(flick_marshal_stream_t _stream, long_list *_data)
{
  flick_iiop_decode_new_glob(4);
  flick_iiop_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->long_list_len);
  flick_iiop_decode_end_chunk(4);
  flick_iiop_decode_end_glob(4);
  flick_iiop_decode_new_glob(4 * _data->long_list_len);
  flick_iiop_decode_new_chunk(4 * _data->long_list_len);
  _data->long_list_val = sun_flick_alloc(_data->long_list_len * sizeof(int ));
  flick_cdr_decode_bcopy(0, _data->long_list_val, 4 * _data->long_list_len);
  flick_iiop_decode_end_chunk(4 * _data->long_list_len);
  flick_iiop_decode_end_glob(4 * _data->long_list_len);
}

void flick_unmarshal_stub_long_list_swap(flick_marshal_stream_t _stream, long_list *_data)
{
  unsigned int _t0_array_iter;

  flick_iiop_decode_new_glob(4);
  flick_iiop_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->long_list_len);
  flick_iiop_decode_end_chunk(4);
  flick_iiop_decode_end_glob(4);
  flick_iiop_decode_new_glob(4 * _data->long_list_len);
  _data->long_list_val = sun_flick_alloc(_data->long_list_len * sizeof(int ));
  for (_t0_array_iter = 0; _t0_array_iter < _data->long_list_len; _t0_array_iter++)
    {
      flick_iiop_decode_new_chunk(4);
      flick_cdr_swap_decode_signed32(0, _data->long_list_val[_t0_array_iter]);
      flick_iiop_decode_end_chunk(4);
    }
  flick_iiop_decode_end_glob(4 * _data->long_list_len);
}

void flick_marshal_stub_sb_list(flick_marshal_stream_t _stream, const sb_list *_data)
{
  unsigned int _t1_array_iter;

  flick_iiop_encode_new_glob(4);
  flick_iiop_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->sb_list_len);
  flick_iiop_encode_end_chunk(4);
  flick_iiop_encode_end_glob(4);
  flick_iiop_encode_new_glob(16 * _data->sb_list_len);
  for (_t1_array_iter = 0; _t1_array_iter < _data->sb_list_len; _t1_array_iter++)
    {
      flick_iiop_encode_new_chunk(16);
      flick_cdr_encode_signed32(0, _data->sb_list_val[_t1_array_iter].a.a);
      flick_cdr_encode_signed32(4, _data->sb_list_val[_t1_array_iter].a.b);
      flick_cdr_encode_signed32(8, _data->sb_list_val[_t1_array_iter].b.a);
      flick_cdr_encode_signed32(12, _data->sb_list_val[_t1_array_iter].b.b);
      flick_iiop_encode_end_chunk(16);
    }
  flick_iiop_encode_end_glob(16 * _data->sb_list_len);
}

void flick_unmarshal_stub_sb_list(flick_marshal_stream_t _stream, sb_list *_data)
{
  unsigned int _t2_array_iter;

  flick_iiop_decode_new_glob(4);
  flick_iiop_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->sb_list_len);
  flick_iiop_decode_end_chunk(4);
  flick_iiop_decode_end_glob(4);
  flick_iiop_decode_new_glob(16 * _data->sb_list_len);
  _data->sb_list_val = sun_flick_alloc(_data->sb_list_len * sizeof(struct sb ));
  for (_t2_array_iter = 0; _t2_array_iter < _data->sb_list_len; _t2_array_iter++)
    {
      flick_iiop_decode_new_chunk(16);
      flick_cdr_decode_signed32(0, _data->sb_list_val[_t2_array_iter].a.a);
      flick_cdr_decode_signed32(4, _data->sb_list_val[_t2_array_iter].a.b);
      flick_cdr_decode_signed32(8, _data->sb_list_val[_t2_array_iter].b.a);
      flick_cdr_decode_signed32(12, _data->sb_list_val[_t2_array_iter].b.b);
      flick_iiop_decode_end_chunk(16);
    }
  flick_iiop_decode_end_glob(16 * _data->sb_list_len);
}

void flick_unmarshal_stub_sb_list_swap(flick_marshal_stream_t _stream, sb_list *_data)
{
  unsigned int _t3_array_iter;

  flick_iiop_decode_new_glob(4);
  flick_iiop_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->sb_list_len);
  flick_iiop_decode_end_chunk(4);
  flick_iiop_decode_end_glob(4);
  flick_iiop_decode_new_glob(16 * _data->sb_list_len);
  _data->sb_list_val = sun_flick_alloc(_data->sb_list_len * sizeof(struct sb ));
  for (_t3_array_iter = 0; _t3_array_iter < _data->sb_list_len; _t3_array_iter++)
    {
      flick_iiop_decode_new_chunk(16);
      flick_cdr_swap_decode_signed32(0, _data->sb_list_val[_t3_array_iter].a.a);
      flick_cdr_swap_decode_signed32(4, _data->sb_list_val[_t3_array_iter].a.b);
      flick_cdr_swap_decode_signed32(8, _data->sb_list_val[_t3_array_iter].b.a);
      flick_cdr_swap_decode_signed32(12, _data->sb_list_val[_t3_array_iter].b.b);
      flick_iiop_decode_end_chunk(16);
    }
  flick_iiop_decode_end_glob(16 * _data->sb_list_len);
}

flick_operation_success_t math_50(FLICK_BUFFER *InHeadP, FLICK_BUFFER *OutHeadP, unsigned long _request_id, FLICK_CLIENT _this_obj)
{
  FLICK_BUFFER *_stream;
  flick_iiop_server_start_decode();
  if (flick_cdr_swap()) {
  {
    signed int _t23_switch_tag;

    flick_iiop_decode_new_glob(8);
    flick_iiop_decode_new_chunk(4);
    flick_cdr_swap_decode_signed32(0, _t23_switch_tag);
    flick_iiop_decode_end_chunk(4);
    switch ((signed int )_t23_switch_tag)
      {
      case (signed int) 7:
        {
          {
            long_list *_local_arg;
            struct svc_req *_obj;
            int *_return = 0;
            unsigned int _t24_principal_len;
            long_list _t25_storage;
            unsigned int _t26_array_iter;

            {
              flick_iiop_server_decode_target(_obj, 0, cdr);
            }
            /* Skip over the requesting `Principal' pseudo object (security ID). */
            flick_iiop_decode_new_chunk(4);
            flick_cdr_swap_decode_unsigned32(0, _t24_principal_len);
            flick_iiop_decode_end_chunk(4);
            flick_iiop_decode_end_glob(8);
            flick_iiop_decode_new_glob(_t24_principal_len);
            flick_iiop_decode_new_chunk(_t24_principal_len);
            flick_iiop_decode_end_chunk(_t24_principal_len);
            flick_iiop_decode_end_glob(_t24_principal_len);
            /* Begin decode phase on parameters */
            _local_arg = &_t25_storage;
            flick_iiop_decode_new_glob(7);
            flick_iiop_decode_new_chunk_align(4, 2, 0, 0);
            flick_cdr_swap_decode_unsigned32(0, _local_arg->long_list_len);
            flick_iiop_decode_end_chunk(4);
            flick_iiop_decode_end_glob(7);
            flick_iiop_decode_new_glob(4 * _local_arg->long_list_len);
            _local_arg->long_list_val = sun_flick_alloc(_local_arg->long_list_len * sizeof(int ));
            for (_t26_array_iter = 0; _t26_array_iter < _local_arg->long_list_len; _t26_array_iter++)
              {
                flick_iiop_decode_new_chunk(4);
                flick_cdr_swap_decode_signed32(0, _local_arg->long_list_val[_t26_array_iter]);
                flick_iiop_decode_end_chunk(4);
              }
            flick_iiop_decode_end_glob(4 * _local_arg->long_list_len);
            flick_iiop_server_end_decode();
            flick_sun_init_environment();
            _return = long_test_50(_local_arg, _obj);
            flick_iiop_server_start_encode();
            {
              flick_iiop_server_encode_target(_obj, 0, cdr);
            }
            flick_iiop_encode_new_glob(8);
            flick_iiop_encode_new_chunk(4);
            flick_cdr_encode_signed32(0, flick_errno);
            flick_iiop_encode_end_chunk(4);
            switch (flick_errno)
              {
              case 0:
                {
                  /* Begin encode phase on parameters */
                  flick_iiop_encode_new_chunk(4);
                  flick_cdr_encode_signed32(0, *_return);
                  flick_iiop_encode_end_chunk(4);
                  flick_iiop_encode_end_glob(8);
                  break;
                }
              case -1:
                {
                  flick_iiop_encode_end_glob(8);
                  flick_sun_encode_system_exception("no data available", cdr, iiop);
                  break;
                }
              default:
                {
                  flick_sun_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VIRTUAL_UNION, cdr, iiop);
                  flick_iiop_encode_end_glob(8);
                }
              }
            flick_iiop_server_end_encode();
          }
          break;
        }
      case (signed int) 8:
        {
          {
            sb_list *_local_arg;
            struct svc_req *_obj;
            int *_return = 0;
            unsigned int _t27_principal_len;
            sb_list _t28_storage;
            unsigned int _t29_array_iter;

            {
              flick_iiop_server_decode_target(_obj, 0, cdr);
            }
            /* Skip over the requesting `Principal' pseudo object (security ID). */
            flick_iiop_decode_new_chunk(4);
            flick_cdr_swap_decode_unsigned32(0, _t27_principal_len);
            flick_iiop_decode_end_chunk(4);
            flick_iiop_decode_end_glob(8);
            flick_iiop_decode_new_glob(_t27_principal_len);
            flick_iiop_decode_new_chunk(_t27_principal_len);
            flick_iiop_decode_end_chunk(_t27_principal_len);
            flick_iiop_decode_end_glob(_t27_principal_len);
            /* Begin decode phase on parameters */
            _local_arg = &_t28_storage;
            flick_iiop_decode_new_glob(7);
            flick_iiop_decode_new_chunk_align(4, 2, 0, 0);
            flick_cdr_swap_decode_unsigned32(0, _local_arg->sb_list_len);
            flick_iiop_decode_end_chunk(4);
            flick_iiop_decode_end_glob(7);
            flick_iiop_decode_new_glob(16 * _local_arg->sb_list_len);
            _local_arg->sb_list_val = sun_flick_alloc(_local_arg->sb_list_len * sizeof(struct sb ));
            for (_t29_array_iter = 0; _t29_array_iter < _local_arg->sb_list_len; _t29_array_iter++)
              {
                flick_iiop_decode_new_chunk(16);
                flick_cdr_swap_decode_signed32(0, _local_arg->sb_list_val[_t29_array_iter].a.a);
                flick_cdr_swap_decode_signed32(4, _local_arg->sb_list_val[_t29_array_iter].a.b);
                flick_cdr_swap_decode_signed32(8, _local_arg->sb_list_val[_t29_array_iter].b.a);
                flick_cdr_swap_decode_signed32(12, _local_arg->sb_list_val[_t29_array_iter].b.b);
                flick_iiop_decode_end_chunk(16);
              }
            flick_iiop_decode_end_glob(16 * _local_arg->sb_list_len);
            flick_iiop_server_end_decode();
            flick_sun_init_environment();
            _return = sb_test_50(_local_arg, _obj);
            flick_iiop_server_start_encode();
            {
              flick_iiop_server_encode_target(_obj, 0, cdr);
            }
            flick_iiop_encode_new_glob(8);
            flick_iiop_encode_new_chunk(4);
            flick_cdr_encode_signed32(0, flick_errno);
            flick_iiop_encode_end_chunk(4);
            switch (flick_errno)
              {
              case 0:
                {
                  /* Begin encode phase on parameters */
                  flick_iiop_encode_new_chunk(4);
                  flick_cdr_encode_signed32(0, *_return);
                  flick_iiop_encode_end_chunk(4);
                  flick_iiop_encode_end_glob(8);
                  break;
                }
              case -1:
                {
                  flick_iiop_encode_end_glob(8);
                  flick_sun_encode_system_exception("no data available", cdr, iiop);
                  break;
                }
              default:
                {
                  flick_sun_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VIRTUAL_UNION, cdr, iiop);
                  flick_iiop_encode_end_glob(8);
                }
              }
            flick_iiop_server_end_encode();
          }
          break;
        }
      default:
        {
          flick_sun_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_DECODE_SWITCH, cdr_swap, iiop);
          flick_iiop_decode_end_glob(8);
          break;
        }
      }
  }
  } else {
  {
    signed int _t10_switch_tag;

    flick_iiop_decode_new_glob(8);
    flick_iiop_decode_new_chunk(4);
    flick_cdr_decode_signed32(0, _t10_switch_tag);
    flick_iiop_decode_end_chunk(4);
    switch ((signed int )_t10_switch_tag)
      {
      case (signed int) 7:
        {
          {
            long_list *_local_arg;
            struct svc_req *_obj;
            int *_return = 0;
            unsigned int _t11_principal_len;
            long_list _t12_storage;

            {
              flick_iiop_server_decode_target(_obj, 0, cdr);
            }
            /* Skip over the requesting `Principal' pseudo object (security ID). */
            flick_iiop_decode_new_chunk(4);
            flick_cdr_decode_unsigned32(0, _t11_principal_len);
            flick_iiop_decode_end_chunk(4);
            flick_iiop_decode_end_glob(8);
            flick_iiop_decode_new_glob(_t11_principal_len);
            flick_iiop_decode_new_chunk(_t11_principal_len);
            flick_iiop_decode_end_chunk(_t11_principal_len);
            flick_iiop_decode_end_glob(_t11_principal_len);
            /* Begin decode phase on parameters */
            _local_arg = &_t12_storage;
            flick_iiop_decode_new_glob(7);
            flick_iiop_decode_new_chunk_align(4, 2, 0, 0);
            flick_cdr_decode_unsigned32(0, _local_arg->long_list_len);
            flick_iiop_decode_end_chunk(4);
            flick_iiop_decode_end_glob(7);
            flick_iiop_decode_new_glob(4 * _local_arg->long_list_len);
            flick_iiop_decode_new_chunk(4 * _local_arg->long_list_len);
            _local_arg->long_list_val = sun_flick_alloc(_local_arg->long_list_len * sizeof(int ));
            flick_cdr_decode_bcopy(0, _local_arg->long_list_val, 4 * _local_arg->long_list_len);
            flick_iiop_decode_end_chunk(4 * _local_arg->long_list_len);
            flick_iiop_decode_end_glob(4 * _local_arg->long_list_len);
            flick_iiop_server_end_decode();
            flick_sun_init_environment();
            _return = long_test_50(_local_arg, _obj);
            flick_iiop_server_start_encode();
            {
              flick_iiop_server_encode_target(_obj, 0, cdr);
            }
            flick_iiop_encode_new_glob(8);
            flick_iiop_encode_new_chunk(4);
            flick_cdr_encode_signed32(0, flick_errno);
            flick_iiop_encode_end_chunk(4);
            switch (flick_errno)
              {
              case 0:
                {
                  /* Begin encode phase on parameters */
                  flick_iiop_encode_new_chunk(4);
                  flick_cdr_encode_signed32(0, *_return);
                  flick_iiop_encode_end_chunk(4);
                  flick_iiop_encode_end_glob(8);
                  break;
                }
              case -1:
                {
                  flick_iiop_encode_end_glob(8);
                  flick_sun_encode_system_exception("no data available", cdr, iiop);
                  break;
                }
              default:
                {
                  flick_sun_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VIRTUAL_UNION, cdr, iiop);
                  flick_iiop_encode_end_glob(8);
                }
              }
            flick_iiop_server_end_encode();
          }
          break;
        }
      case (signed int) 8:
        {
          {
            sb_list *_local_arg;
            struct svc_req *_obj;
            int *_return = 0;
            unsigned int _t13_principal_len;
            sb_list _t14_storage;
            unsigned int _t15_array_iter;

            {
              flick_iiop_server_decode_target(_obj, 0, cdr);
            }
            /* Skip over the requesting `Principal' pseudo object (security ID). */
            flick_iiop_decode_new_chunk(4);
            flick_cdr_decode_unsigned32(0, _t13_principal_len);
            flick_iiop_decode_end_chunk(4);
            flick_iiop_decode_end_glob(8);
            flick_iiop_decode_new_glob(_t13_principal_len);
            flick_iiop_decode_new_chunk(_t13_principal_len);
            flick_iiop_decode_end_chunk(_t13_principal_len);
            flick_iiop_decode_end_glob(_t13_principal_len);
            /* Begin decode phase on parameters */
            _local_arg = &_t14_storage;
            flick_iiop_decode_new_glob(7);
            flick_iiop_decode_new_chunk_align(4, 2, 0, 0);
            flick_cdr_decode_unsigned32(0, _local_arg->sb_list_len);
            flick_iiop_decode_end_chunk(4);
            flick_iiop_decode_end_glob(7);
            flick_iiop_decode_new_glob(16 * _local_arg->sb_list_len);
            _local_arg->sb_list_val = sun_flick_alloc(_local_arg->sb_list_len * sizeof(struct sb ));
            for (_t15_array_iter = 0; _t15_array_iter < _local_arg->sb_list_len; _t15_array_iter++)
              {
                flick_iiop_decode_new_chunk(16);
                flick_cdr_decode_signed32(0, _local_arg->sb_list_val[_t15_array_iter].a.a);
                flick_cdr_decode_signed32(4, _local_arg->sb_list_val[_t15_array_iter].a.b);
                flick_cdr_decode_signed32(8, _local_arg->sb_list_val[_t15_array_iter].b.a);
                flick_cdr_decode_signed32(12, _local_arg->sb_list_val[_t15_array_iter].b.b);
                flick_iiop_decode_end_chunk(16);
              }
            flick_iiop_decode_end_glob(16 * _local_arg->sb_list_len);
            flick_iiop_server_end_decode();
            flick_sun_init_environment();
            _return = sb_test_50(_local_arg, _obj);
            flick_iiop_server_start_encode();
            {
              flick_iiop_server_encode_target(_obj, 0, cdr);
            }
            flick_iiop_encode_new_glob(8);
            flick_iiop_encode_new_chunk(4);
            flick_cdr_encode_signed32(0, flick_errno);
            flick_iiop_encode_end_chunk(4);
            switch (flick_errno)
              {
              case 0:
                {
                  /* Begin encode phase on parameters */
                  flick_iiop_encode_new_chunk(4);
                  flick_cdr_encode_signed32(0, *_return);
                  flick_iiop_encode_end_chunk(4);
                  flick_iiop_encode_end_glob(8);
                  break;
                }
              case -1:
                {
                  flick_iiop_encode_end_glob(8);
                  flick_sun_encode_system_exception("no data available", cdr, iiop);
                  break;
                }
              default:
                {
                  flick_sun_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VIRTUAL_UNION, cdr, iiop);
                  flick_iiop_encode_end_glob(8);
                }
              }
            flick_iiop_server_end_encode();
          }
          break;
        }
      default:
        {
          flick_sun_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_DECODE_SWITCH, cdr, iiop);
          flick_iiop_decode_end_glob(8);
          break;
        }
      }
  }
  }
  return FLICK_OPERATION_SUCCESS;
}
