#include "sequence-server.h"

#include <assert.h>
#include <stdio.h>

/* You need to implement this function. */
void register_objects(CORBA_ORB orb, CORBA_BOA boa, int argc, char **argv,
                      CORBA_Environment *ev);

int main(int argc, char **argv)
{
	CORBA_Environment ev;
	CORBA_ORB orb;
	CORBA_BOA boa;
	if (argc < 3) {
		fprintf(stderr, "usage: %s [-ORBipaddr (local host ip address)] -OAport (portnum) ...\n", argv[0]);
		exit(1);
	}

	orb = CORBA_ORB_init(&argc, argv, 0, &ev);
	if (ev._major != CORBA_NO_EXCEPTION) {
		fprintf(stderr, "%s exception: unable to initialize ORB.\n", CORBA_exception_id(&ev));
		exit(1);
	}
	boa = CORBA_ORB_BOA_init(orb, &argc, argv, 0, &ev);
	if (ev._major != CORBA_NO_EXCEPTION) {
		fprintf(stderr, "%s exception: unable to initialize Object adapter.\n", CORBA_exception_id(&ev));
		exit(1);
	}
	register_objects(orb, boa, argc, argv, &ev);
	if (ev._major != CORBA_NO_EXCEPTION)
		fprintf(stderr, "ERROR: unable to register object implementations.\n");
	else {
		CORBA_BOA_impl_is_ready(boa, &ev);
	}
	if (ev._major != CORBA_NO_EXCEPTION) {
		fprintf(stderr, "%s exception encountered.\n", CORBA_exception_id(&ev));
		exit(1);
	}
	return 0;
}
void flick_marshal_stub_vec10(flick_marshal_stream_t _stream, const vec10 *_data)
{
  flick_iiop_encode_new_glob(44);
  flick_iiop_encode_new_chunk(4 + 4 * _data->_length);
  flick_cdr_encode_unsigned32(0, _data->_length);
  if (_data->_length > (unsigned int) 10)
    flick_corba_encode_mu_error(return, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
  flick_cdr_encode_bcopy(4, _data->_buffer, 4 * _data->_length);
  CORBA_flick_free(_data->_buffer);
  flick_iiop_encode_end_chunk(4 + 4 * _data->_length);
  flick_iiop_encode_end_glob(44);
}

void flick_unmarshal_stub_vec10(flick_marshal_stream_t _stream, vec10 *_data)
{
  flick_iiop_decode_new_glob(44);
  flick_iiop_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length);
  _data->_maximum = _data->_length;
  if (_data->_length > (unsigned int) 10)
    flick_corba_decode_mu_error(return, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
  flick_iiop_decode_end_chunk(4);
  flick_iiop_decode_new_chunk(4 * _data->_length);
  _data->_buffer = CORBA_flick_alloc(_data->_length * sizeof(CORBA_long ));
  flick_cdr_decode_bcopy(0, _data->_buffer, 4 * _data->_length);
  flick_iiop_decode_end_chunk(4 * _data->_length);
  flick_iiop_decode_end_glob(44);
}

void flick_unmarshal_stub_vec10_swap(flick_marshal_stream_t _stream, vec10 *_data)
{
  CORBA_unsigned_long _t0_array_iter;

  flick_iiop_decode_new_glob(44);
  flick_iiop_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length);
  _data->_maximum = _data->_length;
  if (_data->_length > (unsigned int) 10)
    flick_corba_decode_mu_error(return, FLICK_ERROR_OUT_OF_BOUNDS, cdr_swap, iiop);
  flick_iiop_decode_end_chunk(4);
  _data->_buffer = CORBA_flick_alloc(_data->_length * sizeof(CORBA_long ));
  for (_t0_array_iter = 0; _t0_array_iter < _data->_length; _t0_array_iter++)
    {
      flick_iiop_decode_new_chunk(4);
      flick_cdr_swap_decode_signed32(0, _data->_buffer[_t0_array_iter]);
      flick_iiop_decode_end_chunk(4);
    }
  flick_iiop_decode_end_glob(44);
}

void flick_marshal_stub_puke(flick_marshal_stream_t _stream, const puke *_data)
{
  flick_iiop_encode_new_glob(4);
  flick_iiop_encode_new_chunk(4);
  flick_cdr_encode_signed32(0, _data->reason);
  flick_iiop_encode_end_chunk(4);
  flick_iiop_encode_end_glob(4);
}

void flick_unmarshal_stub_puke(flick_marshal_stream_t _stream, puke *_data)
{
  flick_iiop_decode_new_glob(4);
  flick_iiop_decode_new_chunk(4);
  flick_cdr_decode_signed32(0, _data->reason);
  flick_iiop_decode_end_chunk(4);
  flick_iiop_decode_end_glob(4);
}

void flick_unmarshal_stub_puke_swap(flick_marshal_stream_t _stream, puke *_data)
{
  flick_iiop_decode_new_glob(4);
  flick_iiop_decode_new_chunk(4);
  flick_cdr_swap_decode_signed32(0, _data->reason);
  flick_iiop_decode_end_chunk(4);
  flick_iiop_decode_end_glob(4);
}

void flick_marshal_stub_TestSeq(flick_marshal_stream_t _stream, const TestSeq *_data)
{
  flick_cdr_encode_IOR(iiop, *_data, 0);
}

void flick_unmarshal_stub_TestSeq(flick_marshal_stream_t _stream, TestSeq *_data)
{
  flick_cdr_decode_IOR(iiop, *_data, 1);
}

void flick_unmarshal_stub_TestSeq_swap(flick_marshal_stream_t _stream, TestSeq *_data)
{
  flick_cdr_swap_decode_IOR(iiop, *_data, 1);
}

flick_operation_success_t TestSeq_server(FLICK_BUFFER *InHeadP, FLICK_BUFFER *OutHeadP, unsigned long _request_id, FLICK_CLIENT _this_obj)
{
  FLICK_BUFFER *_stream;
  flick_iiop_server_start_decode();
  if (flick_cdr_swap()) {
  {
    unsigned int _t27_switch_tag;

    flick_iiop_decode_new_glob(12);
    flick_iiop_decode_new_chunk(4);
    flick_cdr_swap_decode_unsigned32(0, _t27_switch_tag);
    flick_iiop_decode_end_chunk(4);
    switch ((unsigned int )_t27_switch_tag)
      {
      case (unsigned int) 3:
        {
          unsigned short int _t28_switch_tag;

          flick_iiop_decode_new_chunk(2);
          flick_cdr_decode_unsigned16(0, _t28_switch_tag);
          flick_iiop_decode_end_chunk(2);
          switch ((unsigned short int )_t28_switch_tag)
            {
            case /* op */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 28528):
              {
                char _t29_switch_tag;

                flick_iiop_decode_new_chunk(1);
                flick_cdr_swap_decode_char8(0, _t29_switch_tag);
                flick_iiop_decode_end_chunk(1);
                switch ((char )_t29_switch_tag)
                  {
                  case 0:
                    {
                      {
                        TestSeq _obj;
                        vec10 *_local_iv;
                        vec10 **_local_ov;
                        vec10 *_local_iov;
                        CORBA_Environment *_ev;
                        vec10 *_return = 0;
                        unsigned int _t30_principal_len;
                        vec10 _t31_storage;
                        CORBA_unsigned_long _t32_array_iter;
                        vec10 *_t33_storage;
                        vec10 _t34_storage;
                        CORBA_unsigned_long _t35_array_iter;
                        CORBA_Environment _t36_storage;

                        {
                          flick_iiop_server_decode_target(_obj, 0, cdr);
                        }
                        /* Skip over the requesting `Principal' pseudo object (security ID). */
                        flick_iiop_decode_new_chunk(5);
                        flick_cdr_swap_decode_unsigned32(1, _t30_principal_len);
                        flick_iiop_decode_end_chunk(5);
                        flick_iiop_decode_end_glob(12);
                        flick_iiop_decode_new_glob(_t30_principal_len);
                        flick_iiop_decode_new_chunk(_t30_principal_len);
                        flick_iiop_decode_end_chunk(_t30_principal_len);
                        flick_iiop_decode_end_glob(_t30_principal_len);
                        /* Begin decode phase on parameters */
                        _local_iv = &_t31_storage;
                        flick_iiop_decode_new_glob(91);
                        flick_iiop_decode_new_chunk_align(4, 2, 0, 0);
                        flick_cdr_swap_decode_unsigned32(0, _local_iv->_length);
                        _local_iv->_maximum = _local_iv->_length;
                        if (_local_iv->_length > (unsigned int) 10)
                          flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr_swap, iiop);
                        flick_iiop_decode_end_chunk(4);
                        _local_iv->_buffer = auto_flick_alloc(_local_iv->_length * sizeof(CORBA_long ));
                        for (_t32_array_iter = 0; _t32_array_iter < _local_iv->_length; _t32_array_iter++)
                          {
                            flick_iiop_decode_new_chunk(4);
                            flick_cdr_swap_decode_signed32(0, _local_iv->_buffer[_t32_array_iter]);
                            flick_iiop_decode_end_chunk(4);
                          }
                        _local_ov = &_t33_storage;
                        _local_iov = &_t34_storage;
                        flick_iiop_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _local_iov->_length);
                        _local_iov->_maximum = _local_iov->_length;
                        if (_local_iov->_length > (unsigned int) 10)
                          flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr_swap, iiop);
                        flick_iiop_decode_end_chunk(4);
                        _local_iov->_buffer = CORBA_flick_alloc(_local_iov->_length * sizeof(CORBA_long ));
                        for (_t35_array_iter = 0; _t35_array_iter < _local_iov->_length; _t35_array_iter++)
                          {
                            flick_iiop_decode_new_chunk(4);
                            flick_cdr_swap_decode_signed32(0, _local_iov->_buffer[_t35_array_iter]);
                            flick_iiop_decode_end_chunk(4);
                          }
                        _ev = &_t36_storage;
                        flick_iiop_decode_end_glob(91);
                        flick_iiop_server_end_decode();
                        flick_corba_init_environment();
                        _return = TestSeq_op(_obj, _local_iv, _local_ov, _local_iov, _ev);
                        flick_iiop_server_start_encode();
                        {
                          flick_iiop_server_encode_target(_obj, 0, cdr);
                        }
                        flick_iiop_encode_new_glob(136);
                        flick_iiop_encode_new_chunk(4);
                        flick_cdr_encode_signed32(0, _ev->_major);
                        flick_iiop_encode_end_chunk(4);
                        switch (_ev->_major)
                          {
                          case CORBA_NO_EXCEPTION:
                            {
                              /* Begin encode phase on parameters */
                              flick_iiop_encode_new_chunk(4 + 4 * _return->_length);
                              flick_cdr_encode_unsigned32(0, _return->_length);
                              if (_return->_length > (unsigned int) 10)
                                flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
                              flick_cdr_encode_bcopy(4, _return->_buffer, 4 * _return->_length);
                              CORBA_flick_free(_return->_buffer);
                              flick_iiop_encode_end_chunk(4 + 4 * _return->_length);
                              CORBA_flick_free(_return);
                              flick_iiop_encode_new_chunk(4 + 4 * (*_local_ov)->_length);
                              flick_cdr_encode_unsigned32(0, (*_local_ov)->_length);
                              if ((*_local_ov)->_length > (unsigned int) 10)
                                flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
                              flick_cdr_encode_bcopy(4, (*_local_ov)->_buffer, 4 * (*_local_ov)->_length);
                              CORBA_flick_free((*_local_ov)->_buffer);
                              flick_iiop_encode_end_chunk(4 + 4 * (*_local_ov)->_length);
                              CORBA_flick_free(*_local_ov);
                              flick_iiop_encode_new_chunk(4 + 4 * _local_iov->_length);
                              flick_cdr_encode_unsigned32(0, _local_iov->_length);
                              if (_local_iov->_length > (unsigned int) 10)
                                flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
                              flick_cdr_encode_bcopy(4, _local_iov->_buffer, 4 * _local_iov->_length);
                              CORBA_flick_free(_local_iov->_buffer);
                              flick_iiop_encode_end_chunk(4 + 4 * _local_iov->_length);
                              flick_iiop_encode_end_glob(136);
                              break;
                            }
                          case CORBA_SYSTEM_EXCEPTION:
                            {
                              flick_iiop_encode_end_glob(136);
                              flick_corba_encode_system_exception(_ev, cdr, iiop);
                              break;
                            }
                          default:
                            {
                              switch ((unsigned int )(1+strlen(_ev->_id)))
                                {
                                case (unsigned int) 13:
                                  {
                                    switch (*(unsigned int *)(_ev->_id + 0))
                                      {
                                      case /* IDL: */ flick_mem_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                                        {
                                          switch (*(unsigned int *)(_ev->_id + 4))
                                            {
                                            case /* puke */ flick_mem_convert_big_endian_to_local_unsigned32((unsigned int) 1886743397):
                                              {
                                                switch (*(unsigned int *)(_ev->_id + 8))
                                                  {
                                                  case /* :1.0 */ flick_mem_convert_big_endian_to_local_unsigned32((unsigned int) 976301616):
                                                    {
                                                      switch (*(char *)(_ev->_id + 12))
                                                        {
                                                        case 0:
                                                          {
                                                            flick_iiop_encode_new_chunk(24);
                                                            flick_cdr_encode_unsigned32(0, 13);
                                                            flick_cdr_encode_char8(4, 'I');
                                                            flick_cdr_encode_char8(5, 'D');
                                                            flick_cdr_encode_char8(6, 'L');
                                                            flick_cdr_encode_char8(7, ':');
                                                            flick_cdr_encode_char8(8, 'p');
                                                            flick_cdr_encode_char8(9, 'u');
                                                            flick_cdr_encode_char8(10, 'k');
                                                            flick_cdr_encode_char8(11, 'e');
                                                            flick_cdr_encode_char8(12, ':');
                                                            flick_cdr_encode_char8(13, '1');
                                                            flick_cdr_encode_char8(14, '.');
                                                            flick_cdr_encode_char8(15, '0');
                                                            flick_cdr_encode_char8(16, 0);
                                                            flick_cdr_encode_signed32(20, ((puke *)(_ev->_value._user_except))->reason);
                                                            CORBA_flick_free((puke *)(_ev->_value._user_except));
                                                            flick_iiop_encode_end_chunk(24);
                                                            break;
                                                          }
                                                        default:
                                                          {
                                                            flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                                            break;
                                                          }
                                                        }
                                                      break;
                                                    }
                                                  default:
                                                    {
                                                      flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                                      break;
                                                    }
                                                  }
                                                break;
                                              }
                                            default:
                                              {
                                                flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                                break;
                                              }
                                            }
                                          break;
                                        }
                                      default:
                                        {
                                          flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                          break;
                                        }
                                      }
                                    break;
                                  }
                                default:
                                  {
                                    flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                    break;
                                  }
                                }
                              flick_iiop_encode_end_glob(136);
                            }
                          }
                        flick_iiop_server_end_encode();
                      }
                      break;
                    }
                  default:
                    {
                      flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_DECODE_SWITCH, cdr_swap, iiop);
                      flick_iiop_decode_end_glob(12);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_DECODE_SWITCH, cdr_swap, iiop);
                flick_iiop_decode_end_glob(12);
                break;
              }
            }
          break;
        }
      default:
        {
          flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_DECODE_SWITCH, cdr_swap, iiop);
          flick_iiop_decode_end_glob(12);
          break;
        }
      }
  }
  } else {
  {
    unsigned int _t9_switch_tag;

    flick_iiop_decode_new_glob(12);
    flick_iiop_decode_new_chunk(4);
    flick_cdr_decode_unsigned32(0, _t9_switch_tag);
    flick_iiop_decode_end_chunk(4);
    switch ((unsigned int )_t9_switch_tag)
      {
      case (unsigned int) 3:
        {
          unsigned short int _t10_switch_tag;

          flick_iiop_decode_new_chunk(2);
          flick_cdr_decode_unsigned16(0, _t10_switch_tag);
          flick_iiop_decode_end_chunk(2);
          switch ((unsigned short int )_t10_switch_tag)
            {
            case /* op */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 28528):
              {
                char _t11_switch_tag;

                flick_iiop_decode_new_chunk(1);
                flick_cdr_decode_char8(0, _t11_switch_tag);
                flick_iiop_decode_end_chunk(1);
                switch ((char )_t11_switch_tag)
                  {
                  case 0:
                    {
                      {
                        TestSeq _obj;
                        vec10 *_local_iv;
                        vec10 **_local_ov;
                        vec10 *_local_iov;
                        CORBA_Environment *_ev;
                        vec10 *_return = 0;
                        unsigned int _t12_principal_len;
                        vec10 _t13_storage;
                        vec10 *_t14_storage;
                        vec10 _t15_storage;
                        CORBA_Environment _t16_storage;

                        {
                          flick_iiop_server_decode_target(_obj, 0, cdr);
                        }
                        /* Skip over the requesting `Principal' pseudo object (security ID). */
                        flick_iiop_decode_new_chunk(5);
                        flick_cdr_decode_unsigned32(1, _t12_principal_len);
                        flick_iiop_decode_end_chunk(5);
                        flick_iiop_decode_end_glob(12);
                        flick_iiop_decode_new_glob(_t12_principal_len);
                        flick_iiop_decode_new_chunk(_t12_principal_len);
                        flick_iiop_decode_end_chunk(_t12_principal_len);
                        flick_iiop_decode_end_glob(_t12_principal_len);
                        /* Begin decode phase on parameters */
                        _local_iv = &_t13_storage;
                        flick_iiop_decode_new_glob(91);
                        flick_iiop_decode_new_chunk_align(4, 2, 0, 0);
                        flick_cdr_decode_unsigned32(0, _local_iv->_length);
                        _local_iv->_maximum = _local_iv->_length;
                        if (_local_iv->_length > (unsigned int) 10)
                          flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
                        flick_iiop_decode_end_chunk(4);
                        flick_iiop_decode_new_chunk(4 * _local_iv->_length);
                        flick_cdr_decode_msgptr(0, _local_iv->_buffer);
                        flick_iiop_decode_end_chunk(4 * _local_iv->_length);
                        _local_ov = &_t14_storage;
                        _local_iov = &_t15_storage;
                        flick_iiop_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _local_iov->_length);
                        _local_iov->_maximum = _local_iov->_length;
                        if (_local_iov->_length > (unsigned int) 10)
                          flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
                        flick_iiop_decode_end_chunk(4);
                        flick_iiop_decode_new_chunk(4 * _local_iov->_length);
                        _local_iov->_buffer = CORBA_flick_alloc(_local_iov->_length * sizeof(CORBA_long ));
                        flick_cdr_decode_bcopy(0, _local_iov->_buffer, 4 * _local_iov->_length);
                        flick_iiop_decode_end_chunk(4 * _local_iov->_length);
                        _ev = &_t16_storage;
                        flick_iiop_decode_end_glob(91);
                        flick_iiop_server_end_decode();
                        flick_corba_init_environment();
                        _return = TestSeq_op(_obj, _local_iv, _local_ov, _local_iov, _ev);
                        flick_iiop_server_start_encode();
                        {
                          flick_iiop_server_encode_target(_obj, 0, cdr);
                        }
                        flick_iiop_encode_new_glob(136);
                        flick_iiop_encode_new_chunk(4);
                        flick_cdr_encode_signed32(0, _ev->_major);
                        flick_iiop_encode_end_chunk(4);
                        switch (_ev->_major)
                          {
                          case CORBA_NO_EXCEPTION:
                            {
                              /* Begin encode phase on parameters */
                              flick_iiop_encode_new_chunk(4 + 4 * _return->_length);
                              flick_cdr_encode_unsigned32(0, _return->_length);
                              if (_return->_length > (unsigned int) 10)
                                flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
                              flick_cdr_encode_bcopy(4, _return->_buffer, 4 * _return->_length);
                              CORBA_flick_free(_return->_buffer);
                              flick_iiop_encode_end_chunk(4 + 4 * _return->_length);
                              CORBA_flick_free(_return);
                              flick_iiop_encode_new_chunk(4 + 4 * (*_local_ov)->_length);
                              flick_cdr_encode_unsigned32(0, (*_local_ov)->_length);
                              if ((*_local_ov)->_length > (unsigned int) 10)
                                flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
                              flick_cdr_encode_bcopy(4, (*_local_ov)->_buffer, 4 * (*_local_ov)->_length);
                              CORBA_flick_free((*_local_ov)->_buffer);
                              flick_iiop_encode_end_chunk(4 + 4 * (*_local_ov)->_length);
                              CORBA_flick_free(*_local_ov);
                              flick_iiop_encode_new_chunk(4 + 4 * _local_iov->_length);
                              flick_cdr_encode_unsigned32(0, _local_iov->_length);
                              if (_local_iov->_length > (unsigned int) 10)
                                flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_OUT_OF_BOUNDS, cdr, iiop);
                              flick_cdr_encode_bcopy(4, _local_iov->_buffer, 4 * _local_iov->_length);
                              CORBA_flick_free(_local_iov->_buffer);
                              flick_iiop_encode_end_chunk(4 + 4 * _local_iov->_length);
                              flick_iiop_encode_end_glob(136);
                              break;
                            }
                          case CORBA_SYSTEM_EXCEPTION:
                            {
                              flick_iiop_encode_end_glob(136);
                              flick_corba_encode_system_exception(_ev, cdr, iiop);
                              break;
                            }
                          default:
                            {
                              switch ((unsigned int )(1+strlen(_ev->_id)))
                                {
                                case (unsigned int) 13:
                                  {
                                    switch (*(unsigned int *)(_ev->_id + 0))
                                      {
                                      case /* IDL: */ flick_mem_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                                        {
                                          switch (*(unsigned int *)(_ev->_id + 4))
                                            {
                                            case /* puke */ flick_mem_convert_big_endian_to_local_unsigned32((unsigned int) 1886743397):
                                              {
                                                switch (*(unsigned int *)(_ev->_id + 8))
                                                  {
                                                  case /* :1.0 */ flick_mem_convert_big_endian_to_local_unsigned32((unsigned int) 976301616):
                                                    {
                                                      switch (*(char *)(_ev->_id + 12))
                                                        {
                                                        case 0:
                                                          {
                                                            flick_iiop_encode_new_chunk(24);
                                                            flick_cdr_encode_unsigned32(0, 13);
                                                            flick_cdr_encode_char8(4, 'I');
                                                            flick_cdr_encode_char8(5, 'D');
                                                            flick_cdr_encode_char8(6, 'L');
                                                            flick_cdr_encode_char8(7, ':');
                                                            flick_cdr_encode_char8(8, 'p');
                                                            flick_cdr_encode_char8(9, 'u');
                                                            flick_cdr_encode_char8(10, 'k');
                                                            flick_cdr_encode_char8(11, 'e');
                                                            flick_cdr_encode_char8(12, ':');
                                                            flick_cdr_encode_char8(13, '1');
                                                            flick_cdr_encode_char8(14, '.');
                                                            flick_cdr_encode_char8(15, '0');
                                                            flick_cdr_encode_char8(16, 0);
                                                            flick_cdr_encode_signed32(20, ((puke *)(_ev->_value._user_except))->reason);
                                                            CORBA_flick_free((puke *)(_ev->_value._user_except));
                                                            flick_iiop_encode_end_chunk(24);
                                                            break;
                                                          }
                                                        default:
                                                          {
                                                            flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                                            break;
                                                          }
                                                        }
                                                      break;
                                                    }
                                                  default:
                                                    {
                                                      flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                                      break;
                                                    }
                                                  }
                                                break;
                                              }
                                            default:
                                              {
                                                flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                                break;
                                              }
                                            }
                                          break;
                                        }
                                      default:
                                        {
                                          flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                          break;
                                        }
                                      }
                                    break;
                                  }
                                default:
                                  {
                                    flick_corba_encode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_VOID_UNION, cdr, iiop);
                                    break;
                                  }
                                }
                              flick_iiop_encode_end_glob(136);
                            }
                          }
                        flick_iiop_server_end_encode();
                      }
                      break;
                    }
                  default:
                    {
                      flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_DECODE_SWITCH, cdr, iiop);
                      flick_iiop_decode_end_glob(12);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_DECODE_SWITCH, cdr, iiop);
                flick_iiop_decode_end_glob(12);
                break;
              }
            }
          break;
        }
      default:
        {
          flick_corba_decode_server_error(return FLICK_OPERATION_SUCCESS, FLICK_ERROR_DECODE_SWITCH, cdr, iiop);
          flick_iiop_decode_end_glob(12);
          break;
        }
      }
  }
  }
  return FLICK_OPERATION_SUCCESS;
}
